@@ -1,7 +1,10 @@
 #' Import spatial data.
 #'
-#' Simple function to read spatial data into a SpatialPolygonsDataFrame. Based on st_read from package sf.
-#' @param file A file path pointing to a shapefile or GeoJSON file, or a character string holding GeoJSON data. See the \code{dsn} argument of \code{\link[sf]{st_read}} for more details.
+#' Simple function to read spatial data into a SpatialPolygonsDataFrame.
+#' Based on st_read from package sf.
+#' @param file A file path pointing to a shapefile or GeoJSON file, or a
+#' character string holding GeoJSON data. See the \code{dsn} argument of
+#' \code{\link[sf]{st_read}} for more details.
 #' @importFrom sf st_read
 #' @importFrom sp CRS
 #' @export
@@ -12,7 +15,7 @@ read_polygons <- function(file) {
   shape <- sf::st_read(file)
   shape <- methods::as(shape, "Spatial")
 
-  if (class(shape) != "SpatialPolygonsDataFrame")
+  if (!inherits(shape, "SpatialPolygonsDataFrame"))
     stop("Please ensure you are using polygons")
 
   shape@proj4string <- sp::CRS(as.character(NA))
